//selection: 7, 20, 7, 29
//name: i -> first
package simple.out;

public class Expression5 {
	public void m(int first) {
		int a= 1 - first;
	}
	public void use() {
		m(2 + 3);
	}
}
